==> eyflutter_uikit-0.0.8%2B8.tar.gz: android/src/main/java/com/basic/eyflutter_uikit/pickers/utils/PickUtils.java <==
package com.basic.eyflutter_uikit.pickers.utils;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Color;
import android.media.MediaMetadataRetriever;
import android.net.Uri;
import android.provider.MediaStore;
import android.text.TextUtils;

import com.basic.eyflutter_core.enums.DirectoryNames;
import com.basic.eyflutter_uikit.pickers.PickerService;
import com.basic.eyflutter_uikit.pickers.PickersConstants;
import com.basic.eyflutter_uikit.pickers.beans.MediaDirectory;
import com.basic.eyflutter_uikit.pickers.beans.PickBean;
import com.basic.eyflutter_uikit.pickers.beans.PickersLangs;
import com.basic.eyflutter_uikit.pickers.enums.PickBehavior;
import com.cloud.eyutils.storage.files.DirectoryUtils;
import com.cloud.eyutils.storage.files.StorageUtils;
import com.cloud.eyutils.utils.GlobalUtils;
import com.yalantis.ucrop.UCrop;
import com.yalantis.ucrop.UCropActivity;

import java.io.File;
import java.util.LinkedList;
import java.util.List;

public class PickUtils {
    private static PickUtils pickUtils;

    public static PickUtils getInstance() {
        if (pickUtils == null) {
            synchronized (PickUtils.class) {
                if (pickUtils == null) {
                    pickUtils = new PickUtils();
                }
            }
        }
        return pickUtils;
    }

    private PickBean pickBean;
    private PickersLangs langs;
    private File cameraFile;
    private int spec = 6;

    public void clean() {
        pickBean = null;
        langs = null;
    }

    public PickBean getPickBean() {
        return pickBean == null ? pickBean = new PickBean() : pickBean;
    }

    public void setPickBean(PickBean pickBean) {
        this.pickBean = pickBean;
    }

    public PickersLangs getLangs() {
        return langs == null ? langs = new PickersLangs() : langs;
    }

    public void setLangs(PickersLangs langs) {
        this.langs = langs;
    }

    public boolean isVideo(String pictureType) {
        if (TextUtils.isEmpty(pictureType)) {
            return false;
        }
        switch (pictureType) {
            case "video/3gp":
            case "video/3gpp":
            case "video/3gpp2":
            case "video/avi":
            case "video/mp4":
            case "video/quicktime":
            case "video/x-msvideo":
            case "video/x-matroska":
            case "video/mpeg":
            case "video/webm":
            case "video/mp2ts":
                return true;
        }
        return false;
    }

    public long getVideoDuration(String videoPath) {
        long duration;
        try {
            MediaMetadataRetriever media = new MediaMetadataRetriever();
            media.setDataSource(videoPath);
            duration = Long.parseLong(media.extractMetadata(MediaMetadataRetriever.METADATA_KEY_DURATION));
            media.release();
        } catch (Exception e) {
            return 0;
        }
        return duration;
    }

    public boolean checkImageIsDamage(int width, String media_path) {
        if (width == 0) {
            BitmapFactory.Options options = new BitmapFactory.Options();
            options.inJustDecodeBounds = true;
            BitmapFactory.decodeFile(media_path, options); //filePath代表图片路径
            if (options.mCancel || options.outWidth == -1 || options.outHeight == -1) {
                //表示图片已损毁
                return true;
            }
        }
        return false;
    }

    public File getCameraFile() {
        return cameraFile;
    }

    //启动系统视频录制
    //isRecordVideo:true-录制视频;false-拍照;
    public void startSystemTaking(Activity activity, boolean isRecordVideo) {
        String fileName = String.format("%s.gbfile", GlobalUtils.getGuidNoConnect());
        File directory = DirectoryUtils.getInstance().getDirectory(DirectoryNames.images.name());
        cameraFile = new File(directory, fileName);
        if (!StorageUtils.createFileIfNoExists(cameraFile)) {
            return;
        }
        try {
            Intent intent = new Intent();
            if (isRecordVideo) {
                intent.setAction(MediaStore.ACTION_VIDEO_CAPTURE);
            } else {
                intent.setAction(MediaStore.ACTION_IMAGE_CAPTURE);
            }
            //添加这一句表示对目标应用临时授权该Uri所代表的文件,私有目录读写权限
            intent.setFlags(Intent.FLAG_GRANT_READ_URI_PERMISSION | Intent.FLAG_GRANT_WRITE_URI_PERMISSION);
            intent.putExtra(MediaStore.EXTRA_OUTPUT, Uri.fromFile(cameraFile));
            if (isRecordVideo) {
                activity.startActivityForResult(intent, PickersConstants.CAMERA_REQUEST_VIDEO_CODE);
            } else {
                activity.startActivityForResult(intent, PickersConstants.CAMERA_REQUEST_IMAGE_CODE);
            }
        } catch (Exception e) {
            StorageUtils.deleteQuietly(cameraFile);
        }
    }

    //调用系统拍照、录制结果处理
    public void cameraResultHandle(Context context, int requestCode, int resultCode) {
        if (resultCode != Activity.RESULT_OK) {
            return;
        }
        if (requestCode == PickersConstants.CAMERA_REQUEST_IMAGE_CODE || requestCode == PickersConstants.CAMERA_REQUEST_VIDEO_CODE) {
            File cameraFile = PickUtils.getInstance().getCameraFile();
            if (cameraFile == null || !cameraFile.exists()) {
                return;
            }
            PickerService pickerService = new PickerService();
            List<File> files = new LinkedList<>();
            files.add(cameraFile);
            if (requestCode == PickersConstants.CAMERA_REQUEST_IMAGE_CODE) {
                PickBean pickBean = PickUtils.getInstance().getPickBean();
                if (pickBean.isStartCompression()) {
                    List<String> paths = new LinkedList<>();
                    paths.add(cameraFile.getAbsolutePath());
                    CompressionHandler compressionHandler = new CompressionHandler();
                    compressionHandler.startCompressionByPaths(context, paths, (resultFiles) -> {
                        pickerService.onPickResultCall(resultFiles, PickBehavior.taking);
                    });
                } else {
                    pickerService.onPickResultCall(files, PickBehavior.taking);
                }
            } else {
                pickerService.onPickResultCall(files, PickBehavior.record);
            }
        }
    }

    public MediaDirectory getAllPhotoDirectory() {
        MediaDirectory directory = new MediaDirectory();
        directory.setId("ALL");
        directory.setName("All photo");
        return directory;
    }

    public int getSpec() {
        return spec;
    }

    //启动裁剪
    public void startCrop(Activity activity, File sourceFile, File destinationFile, String title, PickBean pickBean) {
        UCrop uCrop = UCrop.of(Uri.fromFile(sourceFile), Uri.fromFile(destinationFile));
        UCrop.Options options = new UCrop.Options();
        options.useSourceImageAspectRatio();
        //设置裁剪图片可操作的手势
        options.setAllowedGestures(UCropActivity.NONE, UCropActivity.NONE, UCropActivity.NONE);
        //设置裁剪的图片质量
        options.setCompressionQuality(100);
        //设置裁剪出来图片的格式
        options.setCompressionFormat(Bitmap.CompressFormat.PNG);
        //可以调整裁剪框
        options.setFreeStyleCropEnabled(true);
        //设置裁剪框圆形
        options.setCircleDimmedLayer(pickBean.isClipCircle());
        //设置是否展示矩形裁剪框
        options.setShowCropFrame(true);
        options.setShowCropGrid(false);
        options.setToolbarTitle(title);
        options.setToolbarColor(Color.WHITE);
        options.setStatusBarColor(Color.WHITE);
        options.setHideBottomControls(true);
        uCrop.withOptions(options);
        uCrop.withAspectRatio(1, 1).start(activity);
    }
}

==> eyflutter_uikit-0.1.4%2B8.tar.gz: android/src/main/java/com/basic/eyflutter_uikit/pickers/utils/PickUtils.java <==
package com.basic.eyflutter_uikit.pickers.utils;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Color;
import android.media.MediaMetadataRetriever;
import android.net.Uri;
import android.provider.MediaStore;
import android.text.TextUtils;

import com.basic.eyflutter_core.enums.DirectoryNames;
import com.basic.eyflutter_uikit.pickers.PickerService;
import com.basic.eyflutter_uikit.pickers.PickersConstants;
import com.basic.eyflutter_uikit.pickers.beans.MediaDirectory;
import com.basic.eyflutter_uikit.pickers.beans.PickBean;
import com.basic.eyflutter_uikit.pickers.beans.PickersLangs;
import com.basic.eyflutter_uikit.pickers.enums.PickBehavior;
import com.cloud.eyutils.storage.files.DirectoryUtils;
import com.cloud.eyutils.storage.files.StorageUtils;
import com.cloud.eyutils.utils.GlobalUtils;
import com.yalantis.ucrop.UCrop;
import com.yalantis.ucrop.UCropActivity;

import java.io.File;
import java.util.LinkedList;
import java.util.List;

public class PickUtils {
    private static PickUtils pickUtils;

    public static PickUtils getInstance() {
        if (pickUtils == null) {
            synchronized (PickUtils.class) {
                if (pickUtils == null) {
                    pickUtils = new PickUtils();
                }
            }
        }
        return pickUtils;
    }

    private PickBean pickBean;
    private PickersLangs langs;
    private File cameraFile;
    private int spec = 6;

    public void clean() {
        pickBean = null;
        langs = null;
    }

    public PickBean getPickBean() {
        return pickBean == null ? pickBean = new PickBean() : pickBean;
    }

    public void setPickBean(PickBean pickBean) {
        this.pickBean = pickBean;
    }

    public PickersLangs getLangs() {
        return langs == null ? langs = new PickersLangs() : langs;
    }

    public void setLangs(PickersLangs langs) {
        this.langs = langs;
    }

    public boolean isVideo(String pictureType) {
        if (TextUtils.isEmpty(pictureType)) {
            return false;
        }
        switch (pictureType) {
            case "video/3gp":
            case "video/3gpp":
            case "video/3gpp2":
            case "video/avi":
            case "video/mp4":
            case "video/quicktime":
            case "video/x-msvideo":
            case "video/x-matroska":
            case "video/mpeg":
            case "video/webm":
            case "video/mp2ts":
                return true;
        }
        return false;
    }

    public long getVideoDuration(String videoPath) {
        long duration;
        try {
            MediaMetadataRetriever media = new MediaMetadataRetriever();
            media.setDataSource(videoPath);
            duration = Long.parseLong(media.extractMetadata(MediaMetadataRetriever.METADATA_KEY_DURATION));
            media.release();
        } catch (Exception e) {
            return 0;
        }
        return duration;
    }

    public boolean checkImageIsDamage(int width, String media_path) {
        if (width == 0) {
            BitmapFactory.Options options = new BitmapFactory.Options();
            options.inJustDecodeBounds = true;
            BitmapFactory.decodeFile(media_path, options); //filePath代表图片路径
            if (options.mCancel || options.outWidth == -1 || options.outHeight == -1) {
                //表示图片已损毁
                return true;
            }
        }
        return false;
    }

    public File getCameraFile() {
        return cameraFile;
    }

    //启动系统视频录制
    //isRecordVideo:true-录制视频;false-拍照;
    public void startSystemTaking(Activity activity, boolean isRecordVideo) {
        String fileName = String.format("%s.%s", GlobalUtils.getGuidNoConnect(), isRecordVideo ? "mp4" : "png");
        File directory = DirectoryUtils.getInstance().getDirectory(DirectoryNames.images.name());
        cameraFile = new File(directory, fileName);
        if (!StorageUtils.createFileIfNoExists(cameraFile)) {
            return;
        }
        try {
            Intent intent = new Intent();
            if (isRecordVideo) {
                intent.setAction(MediaStore.ACTION_VIDEO_CAPTURE);
            } else {
                intent.setAction(MediaStore.ACTION_IMAGE_CAPTURE);
            }
            //添加这一句表示对目标应用临时授权该Uri所代表的文件,私有目录读写权限
            intent.setFlags(Intent.FLAG_GRANT_READ_URI_PERMISSION | Intent.FLAG_GRANT_WRITE_URI_PERMISSION);
            intent.putExtra(MediaStore.EXTRA_OUTPUT, Uri.fromFile(cameraFile));
            if (isRecordVideo) {
                activity.startActivityForResult(intent, PickersConstants.CAMERA_REQUEST_VIDEO_CODE);
            } else {
                activity.startActivityForResult(intent, PickersConstants.CAMERA_REQUEST_IMAGE_CODE);
            }
        } catch (Exception e) {
            StorageUtils.deleteQuietly(cameraFile);
        }
    }

    //调用系统拍照、录制结果处理
    public void cameraResultHandle(Context context, int requestCode, int resultCode) {
        if (resultCode != Activity.RESULT_OK) {
            return;
        }
        if (requestCode == PickersConstants.CAMERA_REQUEST_IMAGE_CODE || requestCode == PickersConstants.CAMERA_REQUEST_VIDEO_CODE) {
            File cameraFile = PickUtils.getInstance().getCameraFile();
            if (cameraFile == null || !cameraFile.exists()) {
                return;
            }
            PickerService pickerService = new PickerService();
            List<File> files = new LinkedList<>();
            files.add(cameraFile);
            if (requestCode == PickersConstants.CAMERA_REQUEST_IMAGE_CODE) {
                PickBean pickBean = PickUtils.getInstance().getPickBean();
                if (pickBean.isStartCompression()) {
                    List<String> paths = new LinkedList<>();
                    paths.add(cameraFile.getAbsolutePath());
                    CompressionHandler compressionHandler = new CompressionHandler();
                    compressionHandler.startCompressionByPaths(context, paths, (resultFiles) -> {
                        pickerService.onPickResultCall(resultFiles, PickBehavior.taking);
                    });
                } else {
                    pickerService.onPickResultCall(files, PickBehavior.taking);
                }
            } else {
                pickerService.onPickResultCall(files, PickBehavior.record);
            }
        }
    }

    public MediaDirectory getAllPhotoDirectory() {
        MediaDirectory directory = new MediaDirectory();
        directory.setId("ALL");
        directory.setName("All photo");
        return directory;
    }

    public int getSpec() {
        return spec;
    }

    //启动裁剪
    public void startCrop(Activity activity, File sourceFile, File destinationFile, String title, PickBean pickBean) {
        UCrop uCrop = UCrop.of(Uri.fromFile(sourceFile), Uri.fromFile(destinationFile));
        UCrop.Options options = new UCrop.Options();
        options.useSourceImageAspectRatio();
        //设置裁剪图片可操作的手势
        options.setAllowedGestures(UCropActivity.NONE, UCropActivity.NONE, UCropActivity.NONE);
        //设置裁剪的图片质量
        options.setCompressionQuality(100);
        //设置裁剪出来图片的格式
        options.setCompressionFormat(Bitmap.CompressFormat.PNG);
        //可以调整裁剪框
        options.setFreeStyleCropEnabled(true);
        //设置裁剪框圆形
        options.setCircleDimmedLayer(pickBean.isClipCircle());
        //设置是否展示矩形裁剪框
        options.setShowCropFrame(true);
        options.setShowCropGrid(false);
        options.setToolbarTitle(title);
        options.setToolbarColor(Color.WHITE);
        options.setStatusBarColor(Color.WHITE);
        options.setHideBottomControls(true);
        uCrop.withOptions(options);
        uCrop.withAspectRatio(1, 1).start(activity);
    }
}
